@@ -75,15 +75,6 @@ public:
         PMOS_RESOURCE src,
         PMOS_RESOURCE dst);
 
-    //!
-    //! \brief    ConvertFormatGmmToMos
-    //! \param    format
-    //!           [in] GMM format (GMM_FORMAT_*)
-    //! \return   MOS_FORMAT
-    //!           Return MOS_FORMAT corresponding to GMM format or Format_Invalid if no mapping
-    //!
-    MOS_FORMAT ConvertFormatGmmToMos(GMM_RESOURCE_FORMAT format);
-
     //!
     //! \brief    MapTileType
     //! \param    flags
@@ -297,6 +288,7 @@ private:
     uint32_t     auxSize     = 0;
     void*        pMainSurface = nullptr;
     void*        pAuxSurface  = nullptr;
+MEDIA_CLASS_DEFINE_END(BltStateXe_Xpm)
 };
 
 #endif // __MEDIA_BLT_COPY_XE_XPM_BASE_H__
\ No newline at end of file
