@@ -685,3 +685,27 @@ MOS_STATUS SfcRenderXe_Lpm_Plus_Base::AddSfcState(
     return MOS_STATUS_SUCCESS;
 }
 
+MOS_STATUS SfcRenderXe_Lpm_Plus_Base::SetMmcParams(PMOS_SURFACE renderTarget, bool isFormatMmcSupported, bool isMmcEnabled)
+{
+    VP_FUNC_CALL();
+    VP_PUBLIC_CHK_NULL_RETURN(renderTarget);
+    VP_PUBLIC_CHK_NULL_RETURN(m_renderData.sfcStateParams);
+
+    if (((renderTarget->Format == Format_A16R16G16B16) ||
+        (renderTarget->Format == Format_A16B16G16R16)) &&
+        renderTarget->CompressionMode == MOS_MMC_RC)
+    {
+        m_renderData.sfcStateParams->bMMCEnable = true;
+        m_renderData.sfcStateParams->MMCMode    = MOS_MMC_RC;
+        VP_RENDER_NORMALMESSAGE("renderTarget->Format % d, m_renderData.sfcStateParams->MMCMode % d", renderTarget->Format, m_renderData.sfcStateParams->MMCMode);
+        return MOS_STATUS_SUCCESS;
+    }
+
+    if (!isFormatMmcSupported && renderTarget->bIsCompressed && renderTarget->CompressionMode == MOS_MMC_RC)
+    {
+        VP_RENDER_ASSERTMESSAGE("CCS not cleaned due to fix function not supported the Format when compression on.");
+    }
+
+    return SfcRenderBase::SetMmcParams(renderTarget, isFormatMmcSupported, isMmcEnabled);
+}
+
