@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2021, Intel Corporation
+* Copyright (c) 2021-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -47,6 +47,12 @@ class CodechalSetting;
 #define CODECHAL_PUBLIC_ASSERTMESSAGE(_message, ...)                                    \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
 
+#define CODECHAL_PUBLIC_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
+
+#define CODECHAL_PUBLIC_WARNINGMESSAGE(_message, ...)                                   \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
+
 #define CODECHAL_PUBLIC_NORMALMESSAGE(_message, ...)                                    \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_PUBLIC, _message, ##__VA_ARGS__)
 
@@ -68,6 +74,12 @@ class CodechalSetting;
 #define CODECHAL_PUBLIC_CHK_NULL_NO_STATUS_RETURN(_ptr)                                 \
     MOS_CHK_NULL_NO_STATUS_RETURN(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_PUBLIC, _ptr)
 
+#define CODECHAL_PUBLIC_CHK_STATUS_WITH_DESTROY_RETURN(_stmt, destroyFunction)                                                                                    \
+    {                                                                                                                                                             \
+        MOS_STATUS sts = (MOS_STATUS)(_stmt);                                                                                                                     \
+        MOS_CHK_COND_WITH_DESTROY_RETURN_VALUE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_ENCODE, (MOS_STATUS_SUCCESS != sts), destroyFunction, sts, "error status!") \
+    }
+
 typedef struct CODECHAL_SSEU_SETTING
 {
     uint8_t ui8NumSlices;
@@ -264,6 +276,8 @@ public:
     //!
     virtual MOS_STATUS EndFrame();
 
+    virtual MOS_STATUS Reformat();
+
     //!
     //! \brief    Performs the operation requested by the codec function.
     //! \param    [in] params
@@ -291,6 +305,40 @@ public:
         void                *status,
         uint16_t            numStatus);
 
+    //!
+    //! \brief    Get Encode Status for Vulkan Query Pool
+    //! \details  Retrieve the necessary status and results for the Vulkan query pool
+    //!           from the status buffer, such as bitstream size, hardware encoding status, bitstream offset
+    //! \param    [in] queryFrameIndex
+    //!               The specified frame index
+    //!           [in] pData
+    //!               Points to the buffer passed by Vulkan for storing the results.
+    //!           [in] dataOffset
+    //!               Starting position for writing to pData
+    //!           [in] is64bit
+    //!               Whether each result is 64-bit, otherwise 32-bit.
+    //!           [in] reportStatus
+    //!               Whether the encode status needs to be returned
+    //!           [in] reportOffset
+    //!               Whether the bitstream offset needs to be returned
+    //!           [in] reportBitstream
+    //!               Whether the bitstream size needs to be returned
+    //! \return   MOS_STATUS
+    //!           MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    virtual MOS_STATUS GetVulkanQueryPoolResults(
+        uint32_t queryFrameIndex,
+        void    *pData,
+        uint64_t dataOffset,
+        bool     is64bit,
+        uint8_t  reportStatus,
+        bool     reportOffset,
+        bool     reportBitstream)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+
     //!
     //! \brief  Destroy codechl state
     //!
