@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2019-2021, Intel Corporation
+* Copyright (c) 2019-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -31,7 +31,7 @@
 
 #include "decode_allocator.h"
 #include "decode_utils.h"
-#include "codechal_hw.h"
+#include "codec_hw_next.h"
 
 namespace decode {
 
@@ -40,9 +40,9 @@ class BufferOpInf
 {
 public:
     virtual ~BufferOpInf() {}
-    virtual MOS_STATUS Init(CodechalHwInterface& hwInterface, DecodeAllocator& allocator, BasicFeature& basicFeature)
+    virtual MOS_STATUS Init(void *hwInterface, DecodeAllocator &allocator, BasicFeature &basicFeature)
     {
-        m_hwInterface  = &hwInterface;
+        m_hwInterface  = hwInterface;
         m_allocator    = &allocator;
         m_basicFeature = &basicFeature;
         return MOS_STATUS_SUCCESS;
@@ -54,12 +54,11 @@ public:
     virtual bool IsAvailable(BufferType* &buffer) { return true; }
     virtual void Destroy(BufferType* &buffer) = 0;
 
-protected:
-    CodechalHwInterface* m_hwInterface  = nullptr;
+    void*                m_hwInterface  = nullptr;
     DecodeAllocator*     m_allocator    = nullptr;
     BasicFeature*        m_basicFeature = nullptr;
 
-MEDIA_CLASS_DEFINE_END(BufferOpInf)
+MEDIA_CLASS_DEFINE_END(decode__BufferOpInf)
 };
 
 template<typename BufferType, typename BufferOp, typename BasicFeature>
@@ -69,7 +68,8 @@ public:
     //!
     //! \brief  RefrenceAssociatedBuffer constructor
     //!
-    RefrenceAssociatedBuffer() {};
+    RefrenceAssociatedBuffer() 
+    {};
 
     //!
     //! \brief  RefrenceAssociatedBuffer deconstructor
@@ -104,7 +104,7 @@ public:
     //! \return  MOS_STATUS
     //!         MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS Init(CodechalHwInterface& hwInterface, DecodeAllocator& allocator, BasicFeature& basicFeature,
+    MOS_STATUS Init(void* hwInterface, DecodeAllocator& allocator, BasicFeature& basicFeature,
                     uint32_t initialAllocNum)
     {
         DECODE_FUNC_CALL();
@@ -146,6 +146,25 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    //!
+    //! \brief  Reactive buffers for current picture
+    //! \param  [in] frameIdx
+    //!         The frame index for current picture
+    //! \param  [in] refFrameList
+    //!         The frame indicies of reference frame list
+    //! \return  MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS ReActiveCurBuffer(uint32_t curFrameIdx, const std::vector<uint32_t> &refFrameList)
+    {
+        DECODE_FUNC_CALL();
+
+        DECODE_CHK_STATUS(DeActiveCurBuffer(curFrameIdx, refFrameList));
+        DECODE_CHK_STATUS(ActiveCurBuffer(curFrameIdx));
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     //!
     //! \brief  Return buffer for current frame
     //! \return  BufferType*
@@ -319,6 +338,38 @@ protected:
         return MOS_STATUS_SUCCESS;
     }
 
+    //!
+    //! \brief  Deactive buffers corresponding to reference list
+    //! \param  [in] curFrameIdx
+    //!         The frame index for current picture
+    //! \param  [in] refFrameList
+    //!         The frame indicies of reference frame list
+    //! \return  MOS_STATUS
+    //!         MOS_STATUS_SUCCESS if success, else fail reason
+    //!
+    MOS_STATUS DeActiveCurBuffer(uint32_t curFrameIdx, const std::vector<uint32_t> &refFrameList)
+    {
+        DECODE_FUNC_CALL();
+
+        auto iter = m_activeBuffers.begin();
+        while (iter != m_activeBuffers.end())
+        {
+            if (iter->first == curFrameIdx)
+            {
+                auto buffer = iter->second;
+                iter        = m_activeBuffers.erase(iter);
+
+                m_availableBuffers.push_back(buffer);
+            }
+            else
+            {
+                ++iter;
+            }
+        }
+
+        return MOS_STATUS_SUCCESS;
+    }
+
     //!
     //! \brief  Check if the index of buffer is persent in current reference list
     //! \param  [in] frameIndex
@@ -355,7 +406,7 @@ protected:
     std::vector<BufferType*>        m_availableBuffers;        //!< Buffers in idle
     BufferType*                     m_currentBuffer = nullptr; //!< Point to buffer of current picture
 
-MEDIA_CLASS_DEFINE_END(RefrenceAssociatedBuffer)
+MEDIA_CLASS_DEFINE_END(decode__RefrenceAssociatedBuffer)
 };
 
 }
