@@ -221,6 +221,7 @@ namespace encode
         dmem->UPD_Asyn = 0;
         dmem->UPD_EnableAdaptiveRounding = m_basicFeature->m_roundingMethod;
         dmem->UPD_AdaptiveTUEnabled = picParams->AdaptiveTUEnabled;
+        dmem->UPD_EnableDeltaQP = picParams->PicFlags.fields.EnableDeltaQP;
 
         if (seqParams->GopRefDist == 16 && m_rcMode == RATECONTROL_CQL)
             dmem->UPD_MaxBRCLevel = 4;
@@ -342,6 +343,8 @@ namespace encode
             dmem->UPD_EnableCDEFUpdate = 0;
             dmem->UPD_EnableLFUpdate   = 0;
         }
+        dmem->UPD_QMatrixEnabled = picParams->wQMatrixFlags.fields.using_qmatrix;
+        dmem->UPD_LADsRatio      = seqParams->SeqFlags.fields.LADsRatio;
 
         return MOS_STATUS_SUCCESS;
     }
@@ -605,6 +608,8 @@ namespace encode
         {
             dmem->INIT_OvershootCBR_pct = (uint16_t)(seqParams->MaxBitRatePerSlidingWindow * 100 / seqParams->TargetBitRate[0]);
         }
+        dmem->INIT_GopPicSize = seqParams->GopPicSize;
+
         return MOS_STATUS_SUCCESS;
     }
 
