@@ -45,6 +45,7 @@ enum AV1_BRC_FRAME_TYPE
     AV1_BRC_FRAME_TYPE_I = 2,
     AV1_BRC_FRAME_TYPE_B1 = 3,
     AV1_BRC_FRAME_TYPE_B2 = 4,
+    AV1_BRC_FRAME_TYPE_B3 = 5,
     AV1_BRC_FRAME_TYPE_INVALID
 
 };
@@ -69,6 +70,9 @@ enum AV1_BRC_FRAME_TYPE
         uint16_t vdencCmd2Offset = 0;
         uint16_t avpPicStateOffset = 0;
         uint16_t secondAvpPicStateOffset = 0;
+        uint16_t pakInsertSlbSize = 0;
+        uint16_t vdencTileSliceStateOffset = 0;
+        uint16_t tileNum = 1;
     };
     //!
     //! \struct Av1BrcPakMmio
