@@ -274,6 +274,13 @@ namespace encode
             params.regionParams[12].presRegion = const_cast<PMOS_RESOURCE>(&m_vdencReadBatchBufferTU7[m_pipeline->m_currRecycledBufIdx][currentPass]);  // Region 12 - Input SLB Buffer (Input TU7)
         }
 
+        if (m_basicFeature->m_hevcSeqParams->LookaheadDepth && m_basicFeature->m_laDataBufferEnabled)
+        {
+            ENCODE_CHK_NULL_RETURN(m_basicFeature->m_LaDataBuffer);
+            ENCODE_CHK_STATUS_RETURN(m_osInterface->pfnSkipResourceSync(m_basicFeature->m_LaDataBuffer));
+            params.regionParams[13].presRegion = m_basicFeature->m_LaDataBuffer;
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
@@ -1124,7 +1131,7 @@ namespace encode
 
     MHW_SETPAR_DECL_SRC(HCP_PIPE_MODE_SELECT, HucBrcUpdatePkt)
     {
-        params.codecStandardSelect = CodecHal_GetStandardFromMode(m_basicFeature->m_mode) - CODECHAL_HCP_BASE;
+        params.codecStandardSelect = CODEC_STANDARD_SELECT_HEVC;
         params.bStreamOutEnabled   = true;
         params.bVdencEnabled       = true;
         params.multiEngineMode     = MHW_VDBOX_HCP_MULTI_ENGINE_MODE_FE_LEGACY;
