@@ -378,42 +378,56 @@ MOS_STATUS VpUserSetting::InitVpUserSetting(MediaUserSettingSharedPtr userSettin
 
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_L0_3DLUT,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_OCL_3DLUT,
         MediaUserSetting::Group::Sequence,
         0,
         true);
 
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_VP_L0_3DLUT_ENABLED,
+        __MEDIA_USER_FEATURE_VALUE_VP_OCL_3DLUT_ENABLED,
         MediaUserSetting::Group::Sequence,
         0,
         true);
 
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_L0_FC,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VP_OCL_FC,
         MediaUserSetting::Group::Sequence,
         0,
         true);
 
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_DISABLE_VP_L0_FC_FP,
+        __MEDIA_USER_FEATURE_VALUE_VP_LEGACY_FC_IN_USE,
         MediaUserSetting::Group::Sequence,
         0,
         true);
 
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_VP_L0_FC_ENABLED,
+        __MEDIA_USER_FEATURE_VALUE_DISABLE_VP_OCL_FC_FP,
         MediaUserSetting::Group::Sequence,
         0,
         true);
 
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_VP_L0_FC_REPORT,
+        __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_SUPPORTED,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+     DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_FEATURE_REPORT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_VP_OCL_FC_REPORT,
         MediaUserSetting::Group::Sequence,
         0,
         true);
@@ -425,6 +439,34 @@ MOS_STATUS VpUserSetting::InitVpUserSetting(MediaUserSettingSharedPtr userSettin
         0,
         true);
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VEBOX_ID_REPORT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_USED_VEBOX_ID,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_FALLBACK_SCALING_TO_RENDER_8K_REPORT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
 #endif
 
     return MOS_STATUS_SUCCESS;
