@@ -283,13 +283,6 @@ static const EntrypointMap entrypointMap_VAProfileAV1Profile0_Xe3_Lpm_r0
 #endif
 };
 
-static const EntrypointMap entrypointMap_VAProfileAV1Profile1_Xe3_Lpm_r0
-{
-#if defined(_AV1_ENCODE_VDENC_SUPPORTED)
-    {VAEntrypointEncSlice, &entrypointMap_VAProfileAV1Profile1_Data_Xe3_Lpm_r0},
-#endif
-};
-
 static const EntrypointMap entrypointMap_VAProfileVP9Profile0_Xe3_Lpm_r0
 {
 #if defined(_VP9_ENCODE_VDENC_SUPPORTED)
@@ -404,7 +397,6 @@ static const ProfileMap profileMap_Xe3_Lpm_r0
 
 #if defined(_AV1_ENCODE_VDENC_SUPPORTED) || defined(_AV1_DECODE_SUPPORTED)
     {VAProfileAV1Profile0, &entrypointMap_VAProfileAV1Profile0_Xe3_Lpm_r0},
-    {VAProfileAV1Profile1, &entrypointMap_VAProfileAV1Profile1_Xe3_Lpm_r0},
 #endif
 
 #if defined(_VP9_ENCODE_VDENC_SUPPORTED) || defined(_VP9_DECODE_SUPPORTED)
@@ -467,7 +459,6 @@ static const ProfileMap profileMap_Xe3_Lpm_ext_r0
 
 #if defined(_AV1_ENCODE_VDENC_SUPPORTED) || defined(_AV1_DECODE_SUPPORTED)
     {VAProfileAV1Profile0, &entrypointMap_VAProfileAV1Profile0_Xe3_Lpm_r0},
-    {VAProfileAV1Profile1, &entrypointMap_VAProfileAV1Profile1_Xe3_Lpm_r0},
 #endif
 
 #if defined(_VP9_ENCODE_VDENC_SUPPORTED) || defined(_VP9_DECODE_SUPPORTED)
